summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGuillem Jover <guillem@debian.org>2010-01-02 20:46:38 +0100
committerGuillem Jover <guillem@debian.org>2010-01-02 20:46:38 +0100
commitad3a4ff9fd8ae6ddda77dfb143cc250d65295cd1 (patch)
tree3c428688547d92c20898163a08242a1b227a3b2e
parentff159b0d801a89d6d077c663dd82f0bff839320e (diff)
downloaddpkg-ad3a4ff9fd8ae6ddda77dfb143cc250d65295cd1.tar.gz
Fix misspellings of “explicitly” all over the place
-rw-r--r--ChangeLog.old4
-rw-r--r--debian/changelog5
-rw-r--r--man/dpkg-buildpackage.12
-rw-r--r--man/dpkg-trigger.12
-rwxr-xr-xscripts/dpkg-gensymbols.pl4
-rwxr-xr-xscripts/dpkg-shlibdeps.pl2
6 files changed, 10 insertions, 9 deletions
diff --git a/ChangeLog.old b/ChangeLog.old
index 35cf98eb4..980f1851a 100644
--- a/ChangeLog.old
+++ b/ChangeLog.old
@@ -2460,7 +2460,7 @@
2008-04-02 Raphael Hertzog <hertzog@debian.org>
* scripts/Dpkg/Source/Package.pm, scripts/dpkg-genchanges.pl:
- Explicitely put Checksums-* fields before the Files field so that
+ Explicitly put Checksums-* fields before the Files field so that
the Files field is last. This is a work-around for some braindead
dsc parsers (dupload and sbuild for instance, see #473518 and
#470440).
@@ -5281,7 +5281,7 @@
2007-08-31 Guillem Jover <guillem@debian.org>
* scripts/dpkg-genchanges.pl: Do not leave unknown fields unwarned
- and explicitely ignore all known ones from control file source
+ and explicitly ignore all known ones from control file source
package stanza.
2007-08-30 Guillem Jover <guillem@debian.org>
diff --git a/debian/changelog b/debian/changelog
index a6b9801e1..bf4b33cf9 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -34,6 +34,7 @@ dpkg (1.15.6) UNRELEASED; urgency=low
cause problems for anything using dpkg-dev to build packages as those
are already fatal on that case.
* Add new deb-split(5) man page.
+ * Fix misspellings of “explicitly” all over the place.
[ Updated dpkg translations ]
* French (Christian PERRIER).
@@ -551,7 +552,7 @@ dpkg (1.15.1) unstable; urgency=low
version means that the symbol has always existed in all versions of the
package.
* When dpkg delegates to dpkg-query or dpkg-deb to do the actual work, add
- the "--" marker to explicitely document the end of options so that
+ the "--" marker to explicitly document the end of options so that
arguments starting with a dash are not interpreted as options.
Closes: #293163
Thanks to Bill Allombert for the patch.
@@ -2031,7 +2032,7 @@ dpkg (1.14.6) unstable; urgency=low
* Implement support for Homepage field. Closes: #142324
* Ignore XB- fields instead of XC- fields from control file binary package
stanzas in dpkg-genchanges.
- * Explicitely ignore all known fields from the control file source package
+ * Explicitly ignore all known fields from the control file source package
stanza in dpkg-genchanges, instead of leaving unknown fields unwarned.
* Implement support for Vcs-Browser, Vcs-Arch, Vcs-Bzr, Vcs-Cvs, Vcs-Darcs,
Vcs-Git, Vcs-Hg, Vcs-Mtn and Vcs-Svn fields in control file source
diff --git a/man/dpkg-buildpackage.1 b/man/dpkg-buildpackage.1
index e2c96434d..a851bb739 100644
--- a/man/dpkg-buildpackage.1
+++ b/man/dpkg-buildpackage.1
@@ -243,7 +243,7 @@ or
if
.BR noopt
is specified in DEB_BUILD_OPTIONS). Overriding options can be
-used to explicitely set a
+used to explicitly set a
higher optimization level, or work around compiler bugs, which only
can be seen with some optimization levels (the last opt level "wins").
.TP
diff --git a/man/dpkg-trigger.1 b/man/dpkg-trigger.1
index 8e360a48f..a286e676b 100644
--- a/man/dpkg-trigger.1
+++ b/man/dpkg-trigger.1
@@ -10,7 +10,7 @@ dpkg\-trigger \- a package trigger utility
.RI [ option "...] " command
.
.SH DESCRIPTION
-\fBdpkg\-trigger\fP is a tool to explicitely activate triggers and check
+\fBdpkg\-trigger\fP is a tool to explicitly activate triggers and check
for its support on the running \fBdpkg\fP.
.PP
This can be used by maintainer scripts in complex and conditional
diff --git a/scripts/dpkg-shlibdeps.pl b/scripts/dpkg-shlibdeps.pl
index ce5ba96c4..016d45434 100755
--- a/scripts/dpkg-shlibdeps.pl
+++ b/scripts/dpkg-shlibdeps.pl
@@ -676,7 +676,7 @@ sub extract_from_shlibs {
}
my $depread = defined($4) ? $4 : '';
if (($libname eq $2) && ($libversion eq $3)) {
- # Define dep and end here if the package type explicitely
+ # Define dep and end here if the package type explicitly
# matches. Otherwise if the packagetype is not specified, use
# the dep only as a default that can be overriden by a later
# line
diff --git a/scripts/dpkg-gensymbols.pl b/scripts/dpkg-gensymbols.pl
index 905cc1d99..435bb5b4f 100755
--- a/scripts/dpkg-gensymbols.pl
+++ b/scripts/dpkg-gensymbols.pl
@@ -63,7 +63,7 @@ sub usage {
Options:
-p<package> generate symbols file for package.
-P<packagebuilddir> temporary build dir instead of debian/tmp.
- -e<library> explicitely list libraries to scan.
+ -e<library> explicitly list libraries to scan.
-v<version> version of the packages (defaults to
version extracted from debian/changelog).
-c<level> compare generated symbols file with the
@@ -255,7 +255,7 @@ if ($compare) {
my $list = _g("see diff output below");
if ($symfile->used_wildcards()) {
# If wildcards are used, we don't get a diff, so list
# explicitely symbols which are lost
$list = "\n";
my $cur_soname = "";
foreach my $sym (sort { $a->{soname} cmp $b->{soname} or
@@ -255,7 +255,7 @@ if ($compare) {
if ($symfile->used_wildcards()) {
# If wildcards are used, we don't get a diff, so list
- # explicitely symbols which are lost
+ # explicitly symbols which are lost
$list = "\n";
my $cur_soname = "";